package cz.cvut.kbss.reporting.persistence.dao;

import cz.cvut.kbss.reporting.environment.Generator;
import cz.cvut.kbss.reporting.model.Person;
import cz.cvut.kbss.reporting.persistence.BaseDaoTestRunner;
import org.junit.Test;
import org.springframework.beans.factory.annotation.Autowired;

import static org.junit.Assert.*;

public class PersonDaoTest extends BaseDaoTestRunner {

    @Autowired
    private PersonDao dao;

    @Test
    public void findByUsernameReturnsPersonWithMatchingUsername() {
        final Person person = Generator.generatePerson();
        dao.persist(person);

        final Person result = dao.findByUsername(person.getUsername());
        assertNotNull(result);
        assertEquals(person.getId(), result.getId());
    }

    @Test
    public void findByUsernameReturnsNullForUnknownUsername() {
        assertNull(dao.findByUsername("unknownUsername"));
    }

    @Test
    public void existsReturnsTrueForExistingUsername() {
        final Person person = Generator.generatePerson();
        dao.persist(person);
        assertTrue(dao.exists(person.getUsername()));
    }

    @Test
    public void existsReturnsFalseForUnknownUsername() {
        assertFalse(dao.exists("someArbitraryUsername"));
    }
}